@@ -1,11 +1,19 @@
 import re
 import datetime
 from pathlib import Path
+from enum import Enum
+
+
+Band10 = Enum("Band", "AOT B02 B03 B04 B08 TCI WVP")
+Band20 = Enum("Band", "AOT B02 B03 B04 B05 B06 B07 B11 B12 B8A SCL TCI WVP")
+Band60 = Enum("Band", "AOT B01 B02 B03 B04 B05 B06 B07 B09 B11 B12 B8A SCL TCI WVP")
+
+BandResolution = { Band10: "10", Band20: "20", Band60: "60" }
 
 
 class Tile:
     def __init__(self, path):
-        path = Path(path)
+        self.path = Path(path)
 
         pattern = (
             r"^S2[AB]_MSIL2A_"
@@ -17,7 +25,7 @@ class Tile:
             r"\.SAFE$"
         )
 
-        match = re.match(pattern, path.name, re.IGNORECASE)
+        match = re.match(pattern, self.path.name, re.IGNORECASE)
 
         if not match:
             raise RuntimeError("unable to parse tile name")
@@ -39,3 +47,8 @@ class Tile:
     @property
     def stop(self):
         return datetime.datetime.strptime(self.props["stop"], "%Y%m%dT%H%M%S")
+
+    def get_band(self, band):
+        res = BandResolution[type(band)]
+        tif = next(self.path.glob(f"GRANULE/*/IMG_DATA/R{res}m/*_{band.name}_{res}m.jp2"))
+        return tif
